@@ -2,7 +2,9 @@ import argparse
 from enum import Enum
 from genericpath import isfile
 from runpy import run_path
+from typing import List
 from arkitekt.cli.dev.autoreload import watch_directory_and_restart
+from arkitekt.cli.prod.waitfor import wait_for_connection
 from fakts import Fakts
 from fakts.beacon.beacon import FaktsEndpoint
 from fakts.grants.beacon import BeaconGrant
@@ -24,6 +26,7 @@ class ArkitektOptions(str, Enum):
     LOGOUT = "logout"
     LOGIN = "login"
     RUN = "run"
+    WAIT = "wait"
 
 
 agent_script = f'''
@@ -74,6 +77,7 @@ def main(
     scan_network=None,
     beacon=None,
     template=None,
+    services=[],
 ):
 
     console = Console()
@@ -97,7 +101,7 @@ def main(
             console.print(f"{app_directory} does not have a valid fakts.yaml")
             return
 
-        asyncio.run(watch_directory_and_restart(app_directory, run_script_path))
+        asyncio.run(watch_directory_and_restart(path, entrypoint="run"))
 
     if script == ArkitektOptions.RUN:
 
@@ -128,6 +132,22 @@ def main(
         console.print("Loggin in")
         herre.login()
 
+    if script == ArkitektOptions.WAIT:
+
+        if not os.path.isfile(fakts_path):
+            console.print(
+                f"Directory does not contain a valid fakts.yaml. If you want to login again please reinitiliaze."
+            )
+            return
+
+        fakts = Fakts(grants=[], fakts_path=fakts_path)
+        if not fakts.loaded:
+            console.print(
+                f"Configuration in fakts.yaml is not sufficient please reinitilize through 'arkitekt init {path}'"
+            )
+
+        asyncio.run(wait_for_connection(services))
+
     if script == ArkitektOptions.LOGOUT:
 
         if not os.path.isfile(fakts_path):
@@ -238,6 +258,11 @@ def entrypoint():
     parser.add_argument("--scan-network", type=bool, help="Do you want to refresh")
     parser.add_argument("--beacon", type=str, help="The adress of the beacon")
     parser.add_argument("--template", type=str, help="The run script template")
+    parser.add_argument(
+        "--services",
+        type=str,
+        help="The services you want to connect to (seperated by ,)",
+    )
     args = parser.parse_args()
 
     main(
@@ -247,6 +272,7 @@ def entrypoint():
         refresh=args.refresh,
         scan_network=args.scan_network,
         template=args.template,
+        services=args.services.split(",") if args.services else [],
     )
 
 
