@@ -1,19 +1,18 @@
 from qtpy import QtCore, QtGui, QtWidgets
 from arkitekt.agents.base import Agent
-from arkitekt.agents.qt import QtAgent
+from arkitekt.qt.agent import QtAgent
 from arkitekt.config import ArkitektConfig
 from arkitekt.messages.postman.provide.bounced_provide import BouncedProvideMessage
 from arkitekt.schema.template import Template
 import webbrowser
 
+
 def open_in_arkitekt(path):
     config = ArkitektConfig.from_konfik()
     webbrowser.open(f"http://{config.host}:3000{path}")
 
 
-
 class PortsWrapped(QtWidgets.QWidget):
-
     def __init__(self, ports, title, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.layout = QtWidgets.QVBoxLayout()
@@ -27,19 +26,12 @@ class PortsWrapped(QtWidgets.QWidget):
             qlayout.addWidget(argLabel)
             qlayout.addWidget(argDescription)
 
-        
         self.formGroupBox.setLayout(qlayout)
         self.layout.addWidget(self.formGroupBox)
         self.setLayout(self.layout)
 
 
-
-
-
-
-
 class TemplateDetailWidget(QtWidgets.QWidget):
-
     def __init__(self, template: Template, agent: Agent, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
         self.template = template
@@ -48,7 +40,9 @@ class TemplateDetailWidget(QtWidgets.QWidget):
         name = QtWidgets.QLabel(template.node.name)
         name.setFont(QtGui.QFont("Arial", 16))
 
-        identifier = QtWidgets.QLabel(f"@{template.node.package}/{template.node.interface}")
+        identifier = QtWidgets.QLabel(
+            f"@{template.node.package}/{template.node.interface}"
+        )
         identifier.setFont(QtGui.QFont("Arial", 10))
 
         description = QtWidgets.QLabel(template.node.description)
@@ -57,23 +51,18 @@ class TemplateDetailWidget(QtWidgets.QWidget):
         open_button = QtWidgets.QPushButton("Open in Arkitekt")
         open_button.clicked.connect(self.open_in_arkitekt)
 
-
-
         self.layout.addWidget(name)
         self.layout.addWidget(identifier)
         self.layout.addWidget(description)
 
-
         self.layout.addWidget(PortsWrapped(template.node.args, "Arguments"))
         self.layout.addWidget(PortsWrapped(template.node.kwargs, "Constants"))
         self.layout.addWidget(PortsWrapped(template.node.returns, "Returns"))
 
         for kwarg in template.node.kwargs:
-            kwargLabel = QtWidgets.QLabel(kwarg.typename + " | " + kwarg.key + " | " + str(kwarg.default))
+            kwargLabel = QtWidgets.QLabel(kwarg.typename + " | " + kwarg.key + " | ")
             self.layout.addWidget(kwargLabel)
 
-
-
         self.layout.addWidget(open_button)
         self.setLayout(self.layout)
 
@@ -81,12 +70,7 @@ class TemplateDetailWidget(QtWidgets.QWidget):
         open_in_arkitekt(f"/node/{self.template.node.id}")
 
 
-
-
-
-
 class TemplatesListItemWidget(QtWidgets.QWidget):
-
     def __init__(self, template: Template, agent: Agent, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
         self.template = template
@@ -99,11 +83,12 @@ class TemplatesListItemWidget(QtWidgets.QWidget):
 
         self.dialog = TemplateDetailWidget(self.template, self.agent)
 
-
         node_label = QtWidgets.QLabel(template.node.name)
         node_label.setFont(QtGui.QFont("Arial", 10))
 
-        context_label = QtWidgets.QLabel(f"@{template.node.package}/{template.node.interface}")
+        context_label = QtWidgets.QLabel(
+            f"@{template.node.package}/{template.node.interface}"
+        )
         context_label.setFont(QtGui.QFont("Arial", 8))
 
         leftlayout.addWidget(node_label)
@@ -115,7 +100,7 @@ class TemplatesListItemWidget(QtWidgets.QWidget):
         open_button.clicked.connect(self.open_provision)
 
         self.row.addWidget(left)
-        self.row.addWidget(open_button,  alignment=QtCore.Qt.AlignRight)
+        self.row.addWidget(open_button, alignment=QtCore.Qt.AlignRight)
 
         self.setLayout(self.row)
 
@@ -123,10 +108,7 @@ class TemplatesListItemWidget(QtWidgets.QWidget):
         self.dialog.show()
 
 
-
-
 class TemplatesWidget(QtWidgets.QWidget):
-
     def __init__(self, qt_agent: QtAgent = None, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
         self.agent = qt_agent
@@ -134,13 +116,11 @@ class TemplatesWidget(QtWidgets.QWidget):
         self.listWidget = QtWidgets.QListWidget()
         self.layout.addWidget(self.listWidget)
 
-
         self.agent.provide_signal.connect(self.on_provide)
 
         self.setLayout(self.layout)
         self.provisions = {}
 
-
     def on_provide(self, provide_state):
         if provide_state:
             self.listWidget.clear()
